Package: omopgenerics
Title: Methods and Classes for the OMOP Common Data Model
Version: 1.3.7
Authors@R: c(
    person(
        "Martí", "Català", email = "marti.catalasabate@ndorms.ox.ac.uk", 
        role = c("aut", "cre"), comment = c(ORCID = "0000-0003-3308-9905")
    ),
    person(
        "Edward", "Burn", email = "edward.burn@ndorms.ox.ac.uk", role = c("aut"),
        comment = c(ORCID = "0000-0002-9286-1128")
    ),
    person(
        "Mike", "Du", email = "mike.du@ndorms.ox.ac.uk", role = c("ctb"), 
        comment = c(ORCID = "0000-0002-9517-8834")
    ),
    person(
        "Yuchen", "Guo", email = "yuchen.guo@ndorms.ox.ac.uk", role = c("ctb"),
        comment = c(ORCID = "0000-0002-0847-4855")
    ),
    person(
        "Adam", "Black", email = "black@ohdsi.org", role = c("ctb"),
        comment = c(ORCID = "0000-0001-5576-8701")
    ),
    person(
        "Marta", "Alcalde-Herraiz", 
        email = "marta.alcaldeherraiz@ndorms.ox.ac.uk", role = c("ctb"), 
        comment = c(ORCID = "0009-0002-4405-1814")
    )
    )
Description: Provides definitions of core classes and methods used by analytic 
    pipelines that query the OMOP (Observational Medical Outcomes Partnership) 
    common data model.
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: cli, dbplyr (>= 2.5.1), dplyr, generics, glue, lifecycle,
        methods, purrr, rlang, snakecase, stringi, stringr, tidyr,
        vctrs
Depends: R (>= 4.1)
Suggests: bit64, CDMConnector, covr, duckdb, gt, here, jsonlite, knitr,
        omock, readr, rmarkdown, testthat (>= 3.0.0), withr
URL: https://darwin-eu.github.io/omopgenerics/
BugReports: https://github.com/darwin-eu/omopgenerics/issues
Config/testthat/edition: 3
Config/testthat/parallel: true
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-03-06 23:40:55 UTC; marti
Author: Martí Català [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3308-9905>),
  Edward Burn [aut] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Mike Du [ctb] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Yuchen Guo [ctb] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Adam Black [ctb] (ORCID: <https://orcid.org/0000-0001-5576-8701>),
  Marta Alcalde-Herraiz [ctb] (ORCID:
    <https://orcid.org/0009-0002-4405-1814>)
Maintainer: Martí Català <marti.catalasabate@ndorms.ox.ac.uk>
Repository: CRAN
Date/Publication: 2026-03-07 06:10:20 UTC
Built: R 4.6.0; ; 2026-04-26 17:00:08 UTC; unix
