# Generated by roxygen2: do not edit by hand

S3method("$",cdm_reference)
S3method("$<-",cdm_reference)
S3method("[",codelist)
S3method("[",codelist_with_details)
S3method("[",concept_set_expression)
S3method("[[",cdm_reference)
S3method("[[<-",cdm_reference)
S3method(anti_join,cdm_table)
S3method(arrange,cdm_table)
S3method(as_tibble,codelist)
S3method(as_tibble,codelist_with_details)
S3method(as_tibble,concept_set_expression)
S3method(attrition,cohort_table)
S3method(bind,"NULL")
S3method(bind,codelist)
S3method(bind,codelist_with_details)
S3method(bind,cohort_table)
S3method(bind,concept_set_expression)
S3method(bind,list)
S3method(bind,summarised_result)
S3method(c,codelist)
S3method(c,codelist_with_details)
S3method(c,concept_set_expression)
S3method(cdmDisconnect,cdm_reference)
S3method(cdmDisconnect,local_cdm)
S3method(cdmName,cdm_reference)
S3method(cdmName,cdm_table)
S3method(cdmName,default)
S3method(cdmSource,cdm_reference)
S3method(cdmSource,cdm_table)
S3method(cdmSource,default)
S3method(cdmTableFromSource,local_cdm)
S3method(cdmVersion,cdm_reference)
S3method(cdmVersion,cdm_table)
S3method(cdmVersion,default)
S3method(collapse,cdm_table)
S3method(collect,cdm_reference)
S3method(collect,cdm_table)
S3method(collect,cohort_table)
S3method(compute,cdm_table)
S3method(compute,local_cdm)
S3method(count,cdm_table)
S3method(createTableIndex,cdm_table)
S3method(createTableIndex,default)
S3method(cross_join,cdm_table)
S3method(distinct,cdm_table)
S3method(dropSourceTable,cdm_reference)
S3method(dropSourceTable,local_cdm)
S3method(existingIndexes,cdm_reference)
S3method(existingIndexes,default)
S3method(expectedIndexes,cdm_reference)
S3method(expectedIndexes,default)
S3method(filter,cdm_table)
S3method(full_join,cdm_table)
S3method(group_by,cdm_table)
S3method(inner_join,cdm_table)
S3method(insertCdmTo,cdm_reference)
S3method(insertCdmTo,local_cdm)
S3method(insertFromSource,local_cdm)
S3method(insertTable,cdm_reference)
S3method(insertTable,local_cdm)
S3method(intersect,cdm_table)
S3method(left_join,cdm_table)
S3method(listSourceTables,cdm_reference)
S3method(listSourceTables,local_cdm)
S3method(mutate,cdm_table)
S3method(nest_join,cdm_table)
S3method(pivot_longer,cdm_table)
S3method(pivot_wider,cdm_table)
S3method(print,cdm_reference)
S3method(print,cdm_source)
S3method(print,cdm_source_summary)
S3method(print,codelist)
S3method(print,codelist_with_details)
S3method(print,conceptSetExpression)
S3method(print,concept_set_expression)
S3method(readSourceTable,cdm_reference)
S3method(rename,cdm_table)
S3method(right_join,cdm_table)
S3method(rowwise,cdm_table)
S3method(select,cdm_table)
S3method(semi_join,cdm_table)
S3method(settings,cohort_table)
S3method(settings,summarised_result)
S3method(slice,cdm_table)
S3method(slice_head,cdm_table)
S3method(slice_max,cdm_table)
S3method(slice_min,cdm_table)
S3method(slice_sample,cdm_table)
S3method(slice_tail,cdm_table)
S3method(sourceType,cdm_reference)
S3method(sourceType,cdm_source)
S3method(sourceType,cdm_table)
S3method(sourceType,default)
S3method(str,cdm_reference)
S3method(summarise,cdm_table)
S3method(summary,cdm_reference)
S3method(summary,cdm_source)
S3method(summary,cohort_table)
S3method(summary,local_cdm)
S3method(summary,summarised_result)
S3method(suppress,summarised_result)
S3method(tally,cdm_table)
S3method(tidy,summarised_result)
S3method(ungroup,cdm_table)
S3method(union,cdm_table)
S3method(union_all,cdm_table)
export(achillesColumns)
export(achillesTables)
export(addSettings)
export(additionalColumns)
export(assertCharacter)
export(assertChoice)
export(assertClass)
export(assertDate)
export(assertList)
export(assertLogical)
export(assertNumeric)
export(assertTable)
export(assertTrue)
export(attrition)
export(bind)
export(cdmClasses)
export(cdmDisconnect)
export(cdmFromTables)
export(cdmName)
export(cdmReference)
export(cdmSelect)
export(cdmSource)
export(cdmSourceType)
export(cdmTableFromSource)
export(cdmVersion)
export(checkCohortRequirements)
export(cohortCodelist)
export(cohortColumns)
export(cohortCount)
export(cohortTables)
export(combineStrata)
export(createIndexes)
export(createLogFile)
export(createTableIndex)
export(dropSourceTable)
export(dropTable)
export(emptyAchillesTable)
export(emptyCdmReference)
export(emptyCodelist)
export(emptyCodelistWithDetails)
export(emptyCohortTable)
export(emptyConceptSetExpression)
export(emptyOmopTable)
export(emptySummarisedResult)
export(estimateTypeChoices)
export(existingIndexes)
export(expectedIndexes)
export(exportCodelist)
export(exportConceptSetExpression)
export(exportSummarisedResult)
export(filter)
export(filterAdditional)
export(filterGroup)
export(filterSettings)
export(filterStrata)
export(getCohortId)
export(getCohortName)
export(getPersonIdentifier)
export(groupColumns)
export(importCodelist)
export(importConceptSetExpression)
export(importSummarisedResult)
export(insertCdmTo)
export(insertFromSource)
export(insertTable)
export(isResultSuppressed)
export(isTableEmpty)
export(listSourceTables)
export(logMessage)
export(newAchillesTable)
export(newCdmReference)
export(newCdmSource)
export(newCdmTable)
export(newCodelist)
export(newCodelistWithDetails)
export(newCohortTable)
export(newConceptSetExpression)
export(newLocalSource)
export(newOmopTable)
export(newSummarisedResult)
export(numberRecords)
export(numberSubjects)
export(omopColumns)
export(omopDataFolder)
export(omopTableFields)
export(omopTables)
export(pivotEstimates)
export(readSourceTable)
export(recordCohortAttrition)
export(resultColumns)
export(resultPackageVersion)
export(settings)
export(settingsColumns)
export(sourceType)
export(splitAdditional)
export(splitAll)
export(splitGroup)
export(splitStrata)
export(statusIndexes)
export(strataColumns)
export(summariseLogFile)
export(suppress)
export(tableName)
export(tableSource)
export(tidy)
export(tidyColumns)
export(tmpPrefix)
export(toSnakeCase)
export(transformToSummarisedResult)
export(uniqueId)
export(uniqueTableName)
export(uniteAdditional)
export(uniteGroup)
export(uniteStrata)
export(validateAchillesTable)
export(validateAgeGroupArgument)
export(validateCdmArgument)
export(validateCdmTable)
export(validateCohortArgument)
export(validateCohortIdArgument)
export(validateColumn)
export(validateConceptSetArgument)
export(validateNameArgument)
export(validateNameLevel)
export(validateNameStyle)
export(validateNewColumn)
export(validateOmopTable)
export(validateResultArgument)
export(validateStrataArgument)
export(validateWindowArgument)
importFrom(dplyr,anti_join)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,collapse)
importFrom(dplyr,collect)
importFrom(dplyr,compute)
importFrom(dplyr,count)
importFrom(dplyr,cross_join)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,intersect)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,nest_join)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,slice)
importFrom(dplyr,slice_head)
importFrom(dplyr,slice_max)
importFrom(dplyr,slice_min)
importFrom(dplyr,slice_sample)
importFrom(dplyr,slice_tail)
importFrom(dplyr,summarise)
importFrom(dplyr,tally)
importFrom(dplyr,ungroup)
importFrom(dplyr,union)
importFrom(dplyr,union_all)
importFrom(generics,tidy)
importFrom(lifecycle,deprecated)
importFrom(rlang,"%||%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
